@@ -89,6 +89,7 @@ def extract_metar(data: str) -> list:
     return data[:len(data)-1]
 
 def parse_metar(message: str, year: int, month: int) -> dict:
+    print(f"Parsing message: {message}")
     icaoID = re_ID.match(message).group('id')
     if deu.isUSIdentifier(icaoID):
         decoded = fmh(message)
@@ -370,14 +371,12 @@ def transform(data: str, metadata: str, year: int, month: int) -> Iterator[dict]
 
         conversion_success = {}
 
-        msg, num_rvr, num_vrbrvr, num_pcp, num_obv, num_sky = parse_metar(metar, year, month)
-        tsi = msg['tsi']
-
-        # try:
-        #     msg, num_rvr, num_vrbrvr, num_pcp, num_obv, num_sky = parse_metar(metar, year, month)
-        #     tsi = msg['tsi']
-        # except Exception as e:
-        #     LOGGER.error(f"Error parsing METAR report: {data}. {str(e)}")
+        import pdb; pdb.set_trace()
+        try:
+            msg, num_rvr, num_vrbrvr, num_pcp, num_obv, num_sky = parse_metar(metar, year, month)
+            tsi = msg['tsi']
+        except Exception as e:
+            LOGGER.error(f"Error parsing METAR report: {data}. {str(e)}")
 
         try:
             wsi = tsi_mapping[tsi]
